require 'rack-git-revision/version'

module Rack
  class GitRevision
    def initialize(app, options = {})
      @app = app
      @options = {
        path: '/dev/revision',
        git_path: './.git',
        revision: lambda { |git_path|
          if git_path
            `git --git-dir #{git_path} log -1 --pretty="format:%H"`
          else
            `git log -1 --pretty="format:%H"`
          end
        },
        body: lambda { |revision| revision },
        status: lambda { |revision| revision ? 200 : 404 },
        headers: lambda { |revision| { 'Content-Type' => 'text/plain' } },
      }.merge(options)
    end

    def call(env)
      if env['PATH_INFO'] == @options[:path]
        git_path = @options[:git_path]
        revision = @options[:revision].call(git_path) rescue nil
        body = [@options[:body].call(revision) || 'not found']
        status = @options[:status].call(revision)
        headers = @options[:headers].call(revision)
        [status, headers, body]
      else
        @app.call(env)
      end
    end
  end
end
